@@ -17,10 +17,32 @@ use Carp;
 use English qw(-no_match_vars);
 use Text::Sass::Expr;
 use Text::Sass::Functions;
+use Text::Sass::Token;
 use Data::Dumper;
+use Readonly;
 
-our $VERSION = q[0.97];
-our $DEBUG   = 0;
+our $VERSION = q[1.0.3];
+our $DEBUG     = 0;
+our $FUNCTIONS = [qw(Text::Sass::Functions)];
+
+Readonly::Scalar our $DEBUG_SEPARATOR => 30;
+
+sub import {
+  my ($class, @args) = @_;
+
+  if(!scalar @args % 2) {
+    my $args = {@args};
+    if($args->{Functions}) {
+      for my $functions (@{$args->{Functions}}) {
+        eval "require $functions" or carp qq[Could not require $functions: $EVAL_ERROR]; ## no critic (ProhibitStringyEval)
+
+        push @{$FUNCTIONS}, $functions;
+      }
+    }
+  }
+
+  return 1;
+}
 
 sub new {
   my ($class, $ref) = @_;
@@ -76,7 +98,7 @@ sub scss2css {
 
 sub _parse_sass {
   my ($self, $str, $substash, $symbols, $chain) = @_;
-  $DEBUG and print {*STDERR} q[=]x30, q[begin _parse_sass], q[=]x30, "\n";
+  $DEBUG and print {*STDERR} q[=]x$DEBUG_SEPARATOR, q[begin _parse_sass], q[=]x$DEBUG_SEPARATOR, "\n";
 
   #########
   # insert blank links after code2:
@@ -98,7 +120,7 @@ sub _parse_sass {
     $self->_parse_sass_group($substash, $symbols, $chain, $g);
   }
 
-  $DEBUG and print {*STDERR} q[=]x30, q[ end _parse_sass ], q[=]x30, "\n";
+  $DEBUG and print {*STDERR} q[=]x$DEBUG_SEPARATOR, q[ end _parse_sass ], q[=]x$DEBUG_SEPARATOR, "\n";
 
   return 1;
 }
@@ -426,16 +448,20 @@ sub _parse_css {
   my ($self, $str, $substash, $symbols) = @_;
   $str =~ s{/[*].*?[*]/}{}smxg;
 
+  # Normalize line breaks
+  $str =~ s/\n//sg; ## no critic (RegularExpressions)
+  $str =~ s/;/;\n/sg; ## no critic (RegularExpressions)
+  $str =~ s/{/{\n/sg; ## no critic (RegularExpressions)
+  $str =~ s/}/}\n/sg; ## no critic (RegularExpressions)
+
   #########
   # scss definitions
   #
-  while (my ($def) = ( $str =~ m{^\s*(\$[^\n]*)\;}smx )) {
-    $str =~ s{^\s*\$(\S+)\s*:\s*(.*?)\;}{
-      $symbols->{variables}->{$1} = $2;
-      $DEBUG and carp qq[VARIABLE $1 = $2];
-     q[];
-    }smxegi;
-  }
+  $str =~ s{^\s*\$(\S+)\s*:\s*(.*?)\s*\;}{
+    $symbols->{variables}->{$1} = $2;
+    $DEBUG and carp qq[VARIABLE $1 = $2];
+   q[];
+  }smxegi;
 
   my $groups = $self->_css_nestedgroups($str);
 
@@ -620,14 +646,16 @@ sub _expr {
   my ($self, $stash, $symbols, $expr) = @_;
   my $vars = $symbols->{variables} || {};
 
-  $expr =~ s/\!(\S+)/{$vars->{$1}||"\!$1"}/smxeg;
-  $expr =~ s/\$(\S+)/{$vars->{$1}||"\$$1"}/smxeg;
+  #########
+  # Do variable expansion
+  #
+  $expr =~ s/\!($Text::Sass::Token::IDENT)/{$vars->{$1}||"\!$1"}/smxeg;
+  $expr =~ s/\$($Text::Sass::Token::IDENT)/{$vars->{$1}||"\$$1"}/smxeg;
+
+  # TODO: should have lwp, so that url() will work
 
   {
     # Functions
-    my $functions = Text::Sass::Functions->new;
-
-    # TODO: should have rest, so that url() will work
 
     while ($expr =~ /^(.*?)((\S+)\s*[(]([^)]+)[)](.*)$)/smx) {
       my $start  = $1;
@@ -640,17 +668,19 @@ sub _expr {
       # We want hyphenated 'adjust-hue' to work
       #
       $func =~ s/\-/_/gsmx;
-      if (!$functions->can($func)) {
+      my ($implementor) = [grep { $_->can($func); } @{$FUNCTIONS}]->[0];
+
+      if (!$implementor) {
         $start = $self->_expr($stash, $symbols, $start);
         $end   = $self->_expr($stash, $symbols, $end);
 
-	#########
-	# not happy with this here. It probably at least belongs in Expr
-	# - and should include any other CSS stop-words
-	#
-	if($end =~ /repeat|left|top|right|bottom/smx) { ## no-repeat, repeat-x, repeat-y
-	  $end = q[];
-	}
+        #########
+        # not happy with this here. It probably at least belongs in Expr
+        # - and should include any other CSS stop-words
+        #
+        if($end =~ /repeat|left|top|right|bottom/smx) { ## no-repeat, repeat-x, repeat-y
+          $end = q[];
+        }
 
         $expr  = $start . $mstr . $end;
         last;
@@ -665,8 +695,9 @@ sub _expr {
 	$var = $self->_expr($stash, $symbols, $var);
       }
 
-      my $res = $functions->$func(@vars);
-      $expr =~ s/\Q$mstr\E/$res/smx
+      my $res = $implementor->$func(@vars);
+      $expr =~ s/\Q$mstr\E/$res/smx;
+      last;
     }
   }
 
@@ -713,16 +744,44 @@ __END__
 
 =head1 NAME
 
-Text::Sass
+Text::Sass - A Naieve Perl implementation of Sass & SCSS.
 
 =head1 VERSION
 
-$LastChangedRevision: 75 $
+See Text/Sass.pm
 
 =head1 SYNOPSIS
 
+  use Text::Sass;
+
+  my $sass = Text::Sass->new();
+
+  print $sass->sass2css(<<'EOF');
+  $font-stack:    Helvetica, sans-serif
+  $primary-color: #333
+
+  body
+    font: 100% $font-stack
+    color: $primary-color
+  EOF
+
+  print $sass->scss2css(<<'EOF');
+  $font-stack:    Helvetica, sans-serif;
+  $primary-color: #333;
+
+  body {
+    font: 100% $font-stack;
+    color: $primary-color;
+  }
+  EOF
+
 =head1 DESCRIPTION
 
+This is a pure perl implementation of Sass and SCSS languages.
+Currently it implements only a subset of the specification.
+
+L<Sass project page|http://sass-lang.com>
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new - Constructor - nothing special
@@ -741,39 +800,45 @@ $LastChangedRevision: 75 $
 
   my $sCSS = $oSass->scss2css($sScss);
 
-=head1 DIAGNOSTICS
-
-=head1 CONFIGURATION AND ENVIRONMENT
-
 =head1 DEPENDENCIES
 
 =over
 
-=item strict
+=item L<Readonly|Readonly>
 
-=item warnings
-
-=item Carp
-
-=item English
-
-=item Text::Sass::Expr
-
-=item Text::Sass::Functions
-
-=item Data::Dumper
+=item L<Convert::Color|Convert::Color>
 
 =back
 
 =head1 INCOMPATIBILITIES
 
+All variables are currently global. This can be quite unpleasant.
+
 =head1 BUGS AND LIMITATIONS
 
 See README
 
+=head1 SEE ALSO
+
+L<Text::Sass::XS|Text::Sass::XS> - Perl binding for libsass. Consider using it if
+you need higher level of language conformance and/or faster execution.
+
+L<CSS::Sass|CSS::Sass> - Yet another libsass binding.
+
+L<Plack::Middleware::File::Sass|Plack::Middleware::File::Sass> - Sass and SCSS support for all
+Plack frameworks. Can use this module as one of its backends.
+
 =head1 AUTHOR
 
-$Author: Roger Pettett$
+Roger Pettett E<lt>rmp@psyphi.netE<gt>
+
+=head1 DIAGNOSTICS
+
+ Set $Text::Sass::DEBUG = 1;
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Nothing required beyond $DEBUG
 
 =head1 LICENSE AND COPYRIGHT
 
