@@ -15,20 +15,9 @@ use Text::Sass::Expr;
 use POSIX qw();
 use Readonly;
 
-our $VERSION = 0.1;
+our $VERSION = q[1.0.3];
 Readonly::Scalar my $PERC => 100;
 
-sub new {
-  my ($class, $ref) = @_;
-
-  if(!$ref) {
-    $ref = {};
-  }
-
-  bless $ref, $class;
-  return $ref;
-}
-
 sub _color {
   my ($self, $color) = @_;
 
@@ -254,7 +243,6 @@ sub percentage {
   return ($num * $PERC) . q[%];
 }
 
-
 sub round {
   my ($self, $str) = @_;
 
@@ -320,10 +308,6 @@ $LastChangedRevision: 71 $
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new
-
-Creates a new object.
-
 =head2 rgb(red, green, blue)
 
 Converts triplet into a color.
